import time


class TXT:
    def __init__(self, parent):
        self.parent = parent

    def mms(self, destination: str,
            service_number: str,
            attachment: str,
            trans_id: str = "",
            message: str = "Be The match attempted to send an attachment",
            attachment_type: str = "image"
            ) -> dict:
        if attachment.lower().split(".")[-1] in ['gif', 'jpg', 'png', 'jpeg']:
            attachment_type = "image"
        elif attachment.lower().split(".")[-1] in ["vcf", "vcard"]:
            attachment_type = "contact"
        elif attachment.lower().split(".")[-1] in ["mp4"]:
            attachment_type = "video"
        elif attachment.lower().split(".")[-1] in ["mp3", "wav", "acc"]:
            attachment_type = "audio"
        elif attachment.lower().split(".")[-1] in ["pdf"]:
            attachment_type = "pdf"

        mms_body = {
                        "channel": "mms",
                        "from": service_number,
                        "to": [
                        {
                            "msisdn": [
                                destination
                            ],
                            "correlationId": trans_id
                        }],
                        "content":
                        {
                            "fallbacktext": "MMS attempt failed",
                            "attachments": [
                            {
                                "type": attachment_type,
                                "messageText": message,
                                "mediaUrl": attachment,
                                "duration": 5
                            }]
                        }
                    }
        try:
            connect_response = self.parent.rest.post("/v2/messages", data=mms_body)
        except Exception as err:
            raise Exception(f"Error sending MMS: {err}")
        else:
            return connect_response

    def sms(self, destination: str,
            service_number: str,
            message: str = "",
            trans_id: str = ""
            ) -> dict:

        sms_body = {
                        "channel": "sms",
                        "from": service_number,
                        "to": [
                        {
                            "msisdn": [
                                destination
                            ],
                            "correlationId": trans_id
                        }],
                        "content":
                        {
                            "text": message,
                            "type": "text"
                        }
                    }
        try:
            connect_response = self.parent.rest.post("/v2/messages", data=sms_body)
        except Exception as err:
            raise Exception(f"Error sending SMS: {err}")
        else:
            return connect_response



import requests
import sys
import json
import base64


class REST:
    def __init__(self, key, base_url="https://api.us.webexconnect.io"):
        self.key = key
        self.base_url = base_url

    def get(self, uri: str, params: dict = {}, headers: dict = {}, paging: bool = True) -> dict:
        uri = f"/{uri}" if uri.find('/') != 0 else uri
        if uri.find(self.base_url) > 0:
            uri = uri
        else:
            uri = f"{self.base_url}{uri}"

        headers.update({"Key": self.key,
                        "Content-Type": "applicaton/json"})

        page = 0
        page_count = 1
        rest_response = None
        while page < page_count:
            page += 1
            try:
                response = requests.get(f"{uri}",
                                        headers=headers,
                                        data=params
                                        )
            except Exception as err:
                print(f"GET ERROR: {uri} - {err}", file=sys.stderr)
                return {}
            else:
                if 200 <= response.status_code < 300:
                    try:
                        response = response.json()
                    except:
                        return {}
                    else:
                        if 'links' in response['response'].keys() and response['response']['links']['pages'] > page_count:
                            page_count = response['response']['links']['pages']
                        if response['response'] is None:
                            print(f"REST GET Error: {uri} - {response['status_code']} - {response['description']}",
                                  file=sys.stderr)
                            return {}
                        if rest_response is None:
                            rest_response = response['response']
                        else:
                            for key in rest_response:
                                if isinstance(rest_response[key], list):
                                    rest_response[key].extend(response['response'][key])
                        if page == page_count or paging is False:
                            return rest_response
                        else:
                            uri = response['response']['links']['next']
                else:
                    raise Exception("ERROR GET not successful")

    def post(self, uri: str, data: dict = {}, headers: dict = {}) -> dict:
        uri = f"/{uri}" if uri.find('/') != 0 else uri
        if uri.find(self.base_url) > 0:
            uri = uri
        else:
            uri = f"{self.base_url}{uri}"

        headers.update({"Key": self.key,
                        "Content-Type": "application/json"})
        try:
            response = requests.post(f"{uri}",
                                     headers=headers,
                                     json=data
                                     )
        except Exception as err:
            print(f"POST ERROR: {uri} - {err}", file=sys.stderr)
        else:
            if 199 < response.status_code < 299:
                try:
                    return response.json()
                except:
                    return {"success": True}
            else:
                raise Exception(f"Error send REST Request {uri}: {response.status_code}")

    def patch(self, uri: str, params: dict = {}, headers: dict = {}) -> dict:
        uri = f"/{uri}" if uri.find('/') != 0 else uri
        if uri.find(self.base_url) > 0:
            uri = uri
        else:
            uri = f"{self.base_url}{uri}"

        headers.update({"key": self.key})
        # "Content-Type": "applicaton/json"})

        try:
            response = requests.patch(f"{uri}",
                                      headers=headers,
                                      json=params
                                      ).json()
        except Exception as err:
            print(f"PATCH ERROR: {uri} - {err}", file=sys.stderr)
        else:
            if 'response' not in response.keys() or response['response'] is None:
                print(f"REST PATCH Error: {uri} - {response} - {params}",
                      file=sys.stderr)
                return {}
            return response['response']

    def put(self, uri: str, params: dict = {}, headers: dict = {}) -> dict:
        uri = f"/{uri}" if uri.find('/') != 0 else uri
        if uri.find(self.base_url) > 0:
            uri = uri
        else:
            uri = f"{self.base_url}{uri}"

        headers.update({"key": self.key})
        # "Content-Type": "applicaton/json"})

        try:
            response = requests.put(f"{uri}",
                                    headers=headers,
                                    json=params
                                    ).json()
        except Exception as err:
            print(f"PUT ERROR: {uri} - {err}", file=sys.stderr)
        else:
            if 'response' not in response.keys() or response['response'] is None:
                print(f"REST PUT Error: {uri} - {response} - {params}",
                      file=sys.stderr)
                return {}
            return response['response']



from .REST import REST
import sys
import urllib.parse


class Connect:
    def __init__(self, key: str, group_id: str, base_url: str = "https://contactpolicy-us.imiconnect.io"):
        self.rest = REST(key)
        self.key = key
        self.group_id = group_id
        self.base_url = base_url

    def check(self, number) -> bool:
        try:
            consent = self.rest.get(f"/v1/groups/{self.group_id}/members?address={urllib.parse.quote_plus(number)}")[0]
        except Exception as err:
            print(f"Error obtaining consent: {err}", file=sys.stderr)
            return False
        else:
            if consent['consent'] is True:
                return True
            else:
                return False

    def list(self) -> list:
        try:
            consent = self.rest.get(f"/v1/groups/{self.group_id}/members")
        except Exception as err:
            print(f"Error obtaining consent: {err}", file=sys.stderr)
            return []
        else:
            return consent
